@@ -1,6 +1,6 @@
 ######################################################################
-# $Id: MemoryBackend.pm,v 1.9 2002/04/07 17:04:46 dclinton Exp $
-# Copyright (C) 2001, 2002 DeWitt Clinton  All Rights Reserved
+# $Id: MemoryBackend.pm,v 1.11 2003/04/15 14:46:23 dclinton Exp $
+# Copyright (C) 2001-2003 DeWitt Clinton  All Rights Reserved
 #
 # Software distributed under the License is distributed on an "AS
 # IS" basis, WITHOUT WARRANTY OF ANY KIND, either expressed or
@@ -14,7 +14,7 @@ use strict;
 use Cache::CacheUtils qw( Clone_Data );
 
 
-my $Store_Ref;
+my $Store_Ref = { };
 
 
 sub new
@@ -151,7 +151,7 @@ Original author: DeWitt Clinton <dewitt@unto.net>
 
 Last author:     $Author: dclinton $
 
-Copyright (C) 2001, 2002 DeWitt Clinton
+Copyright (C) 2001-2003 DeWitt Clinton
 
 =cut
 
